==> haskell-tar-conduit-0.3.2-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar-conduit
version: 0.3.2
id: tar-conduit-0.3.2-6l1wfldZAlO27qcvOp9ZCo
key: tar-conduit-0.3.2-6l1wfldZAlO27qcvOp9ZCo
license: MIT
maintainer: michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch
author: Michael Snoyman
homepage: https://github.com/snoyberg/tar-conduit#readme
synopsis: Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.
category: Data Conduit
abi: 89512d0305dba5a63e3a7c238ec45de1
exposed: True
exposed-modules:
    Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules: Data.Conduit.Tar.Unix
import-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tar-conduit-0.3.2
hs-libraries: HStar-conduit-0.3.2-6l1wfldZAlO27qcvOp9ZCo
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-7rushQ980336tJPFaKI7Kn directory-1.3.3.0
    filepath-1.4.2.1 safe-exceptions-0.1.7.0-GNJHNVtFHOED1Krw5Gg94s
    text-1.2.3.1 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html: /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-conduit-0.3.2-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar-conduit
version: 0.3.2
id: tar-conduit-0.3.2-BE9bE3ji022KC0qhZM7MZh
key: tar-conduit-0.3.2-BE9bE3ji022KC0qhZM7MZh
license: MIT
maintainer: michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch
author: Michael Snoyman
homepage: https://github.com/snoyberg/tar-conduit#readme
synopsis: Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.
category: Data Conduit
abi: 11c69ffadd7ab5835ad2fadebef557eb
exposed: True
exposed-modules:
    Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules: Data.Conduit.Tar.Unix
import-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tar-conduit-0.3.2
hs-libraries: HStar-conduit-0.3.2-BE9bE3ji022KC0qhZM7MZh
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-1gVzBfuoPB16x0VLumm9wr directory-1.3.3.0
    filepath-1.4.2.1 safe-exceptions-0.1.7.0-GNJHNVtFHOED1Krw5Gg94s
    text-1.2.3.1 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html: /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
